@@ -1,4 +1,3 @@
-get.sensitivity.obj <- function(lprec)
+get.sensitivity.obj <- function(lprec) {
   .Call(RlpSolve_get_sensitivity_obj, lprec)
-
-
+}
