@@ -1,4 +1,3 @@
-get.sensitivity.rhs <- function(lprec)
+get.sensitivity.rhs <- function(lprec) {
   .Call(RlpSolve_get_sensitivity_rhs, lprec)
-
-
+}
