@@ -1,4 +1,3 @@
-get.solutioncount <- function(lprec)
+get.solutioncount <- function(lprec) {
   .Call(RlpSolve_get_solutioncount, lprec)
-
-
+}
