@@ -1,4 +1,3 @@
-get.variables <- function(lprec)
+get.variables <- function(lprec) {
   .Call(RlpSolve_get_variables, lprec)
-
-
+}
