@@ -293,65 +293,6 @@ void blockWriteBMAT(FILE *output, const char *label, lprec* lp, int first, int l
     fprintf(output, "\n");
 }
 
-/* Do a generic readable data dump of key lp_solve model variables;
-   principally for run difference and debugging purposes */
-MYBOOL REPORT_debugdump(lprec *lp, char *filename, MYBOOL livedata)
-{
-  /* FILE   *output = stdout; */
-  FILE   *output;
-  MYBOOL ok;
-
-  ok = (MYBOOL) ((filename == NULL) || ((output = fopen(filename,"w")) != NULL));
-  if(!ok)
-    return(ok);
-  if((filename == NULL) && (lp->outstream != NULL))
-    output = lp->outstream;
-
-  fprintf(output, "\nGENERAL INFORMATION\n-------------------\n\n");
-  fprintf(output, "Model size:     %d rows (%d equalities, %d Lagrangean), %d columns (%d integers, %d SC, %d SOS, %d GUB)\n",
-                  lp->rows, lp->equalities, get_Lrows(lp), lp->columns,
-      lp->int_vars, lp->sc_vars, SOS_count(lp), GUB_count(lp));
-  fprintf(output, "Data size:      %d model non-zeros, %d invB non-zeros (engine is %s)\n",
-                  get_nonzeros(lp), my_if(lp->invB == NULL, 0, lp->bfp_nonzeros(lp, FALSE)), lp->bfp_name());
-  fprintf(output, "Internal sizes: %d rows allocated, %d columns allocated, %d columns used, %d eta length\n",
-                  lp->rows_alloc, lp->columns_alloc, lp->columns, my_if(lp->invB == NULL, 0, lp->bfp_colcount(lp)));
-  fprintf(output, "Memory use:     %d sparse matrix, %d eta\n",
-                  lp->matA->mat_alloc, my_if(lp->invB == NULL, 0, lp->bfp_memallocated(lp)));
-  fprintf(output, "Parameters:     Maximize=%d, Names used=%d, Scalingmode=%d, Presolve=%d, SimplexPivot=%d\n",
-                  is_maxim(lp), lp->names_used, lp->scalemode, lp->do_presolve, lp->piv_strategy);
-  fprintf(output, "Precision:      EpsValue=%g, EpsPrimal=%g, EpsDual=%g, EpsPivot=%g, EpsPerturb=%g\n",
-                  lp->epsvalue, lp->epsprimal, lp->epsdual, lp->epspivot, lp->epsperturb);
-  fprintf(output, "Stability:      AntiDegen=%d, Improvement=%d, Split variables at=%g\n",
-                  lp->improve, lp->anti_degen, lp->negrange);
-  fprintf(output, "B&B settings:   BB pivot rule=%d, BB branching=%s, BB strategy=%d, Integer precision=%g, MIP gaps=%g,%g\n",
-                  lp->bb_rule, my_boolstr(lp->bb_varbranch), lp->bb_floorfirst, lp->epsint, lp->mip_absgap, lp->mip_relgap);
-
-  fprintf(output, "\nCORE DATA\n---------\n\n");
-  blockWriteINT(output,  "Column starts", lp->matA->col_end, 0, lp->columns);
-  blockWriteINT(output,  "row_type", lp->row_type, 0, lp->rows);
-  blockWriteREAL(output, "orig_rhs", lp->orig_rhs, 0, lp->rows);
-  blockWriteREAL(output, "orig_lowbo", lp->orig_lowbo, 0, lp->sum);
-  blockWriteREAL(output, "orig_upbo", lp->orig_upbo, 0, lp->sum);
-  blockWriteINT(output,  "row_type", lp->row_type, 0, lp->rows);
-  blockWriteBOOL(output, "var_type", lp->var_type, 0, lp->columns, TRUE);
-  blockWriteAMAT(output, "A", lp, 0, lp->rows);
-
-  if(livedata) {
-    fprintf(output, "\nPROCESS DATA\n------------\n\n");
-    blockWriteREAL(output,  "Active rhs", lp->rhs, 0, lp->rows);
-    blockWriteINT(output,  "Basic variables", lp->var_basic, 0, lp->rows);
-    blockWriteBOOL(output, "is_basic", lp->is_basic, 0, lp->sum, TRUE);
-    blockWriteREAL(output, "lowbo", lp->lowbo, 0, lp->sum);
-    blockWriteREAL(output, "upbo", lp->upbo, 0, lp->sum);
-    if(lp->scalars != NULL)
-      blockWriteREAL(output, "scalars", lp->scalars, 0, lp->sum);
-  }
-
-  if(filename != NULL)
-    fclose(output);
-  return(ok);
-}
-
 
 /* High level reports for model results */
 
@@ -696,98 +637,3 @@ void REPORT_modelinfo(lprec *lp, MYBOOL doName, char *datainfo)
   report(lp, NORMAL, "Sets:                             %7d GUB,            %7d SOS.\n",
                          GUB_count(lp), SOS_count(lp));
 }
-
-/* Save a matrix column subset to a MatrixMarket formatted file,
-   say to export the basis matrix for further numerical analysis.
-   If colndx is NULL, then the full constraint matrix is assumed. */
-MYBOOL REPORT_mat_mmsave(lprec *lp, char *filename, int *colndx, MYBOOL includeOF, char *infotext)
-{
-  int         n, m, nz, i, j, k, kk;
-  MATrec      *mat = lp->matA;
-  MM_typecode matcode;
-  FILE        *output; /* = stdout; */
-  MYBOOL      ok;
-  LPSREAL        *acol = NULL;
-  int         *nzlist = NULL;
-
-  /* Open file */
-  ok = (MYBOOL) ((filename == NULL) || ((output = fopen(filename,"w")) != NULL));
-  if(!ok)
-    return(ok);
-  if((filename == NULL) && (lp->outstream != NULL))
-    output = lp->outstream;
-
-  /* Compute column and non-zero counts */
-  if(colndx == lp->var_basic) {
-    if(!lp->basis_valid)
-      return( FALSE );
-    m = lp->rows;
-  }
-  else if(colndx != NULL)
-    m = colndx[0];
-  else
-    m = lp->columns;
-  n = lp->rows;
-  nz = 0;
-
-  for(j = 1; j <= m; j++) {
-    k = (colndx == NULL ? n + j : colndx[j]);
-    if(k > n) {
-      k -= lp->rows;
-      nz += mat_collength(mat, k);
-      if(includeOF && is_OF_nz(lp, k))
-        nz++;
-    }
-    else
-      nz++;
-  }
-  kk = 0;
-  if(includeOF) {
-    n++;   /* Row count */
-    kk++;  /* Row index offset */
-  }
-
-  /* Initialize */
-  mm_initialize_typecode(&matcode);
-  mm_set_matrix(&matcode);
-  mm_set_coordinate(&matcode);
-  mm_set_real(&matcode);
-
-  mm_write_banner(output, matcode);
-  mm_write_mtx_crd_size(output, n+kk, m, nz+(colndx == lp->var_basic ? 1 : 0));
-
-  /* Allocate working arrays for sparse column storage */
-  allocREAL(lp, &acol, n+2, FALSE);
-  allocINT(lp, &nzlist, n+2, FALSE);
-
-  /* Write the matrix non-zero values column-by-column.
-     NOTE: matrixMarket files use 1-based indeces,
-     i.e. first row of a vector has index 1, not 0. */
-  if(infotext != NULL) {
-    fprintf(output, "%%\n");
-    fprintf(output, "%% %s\n", infotext);
-    fprintf(output, "%%\n");
-  }
-  if(includeOF && (colndx == lp->var_basic))
-    fprintf(output, "%d %d %g\n", 1, 1, 1.0);
-  for(j = 1; j <= m; j++) {
-    k = (colndx == NULL ? lp->rows + j : colndx[j]);
-    if(k == 0)
-      continue;
-    nz = obtain_column(lp, k, acol, nzlist, NULL);
-    for(i = 1; i <= nz; i++) {
-      if(!includeOF && (nzlist[i] == 0))
-        continue;
-      fprintf(output, "%d %d %g\n", nzlist[i]+kk, j+kk, acol[i]);
-    }
-  }
-  fprintf(output, "%% End of MatrixMarket file\n");
-
-  /* Finish */
-  FREE(acol);
-  FREE(nzlist);
-  fclose(output);
-
-  return(ok);
-}
-
